
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.7'
version = '1.2.7'
full_version = '1.2.7'
git_revision = '3c670e2dceed963e3a537c1d0879a68d2c223d94'
release = True

if not release:
    version = full_version
    short_version += ".dev"
